summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb/utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/kexidb/utils.h')
-rw-r--r--kexi/kexidb/utils.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kexi/kexidb/utils.h b/kexi/kexidb/utils.h
index b8ee03b5..ec807d34 100644
--- a/kexi/kexidb/utils.h
+++ b/kexi/kexidb/utils.h
@@ -259,7 +259,7 @@ namespace KexiDB
(within a second thread).
\a data is used to perform a (temporary) test connection. \a msgHandler is used to display errors.
On successful connecting, a message is displayed. After testing, temporary connection is closed. */
- KEXI_DB_EXPORT void connectionTestDialog(TQWidget* tqparent, const ConnectionData& data,
+ KEXI_DB_EXPORT void connectionTestDialog(TQWidget* parent, const ConnectionData& data,
MessageHandler& msgHandler);
/*! Saves connection data \a data into \a map. */
@@ -349,7 +349,7 @@ namespace KexiDB
/*! Convenience version of loadPropertyValueFromDom(). \return TQString value. */
KEXI_DB_EXPORT TQString loadStringPropertyValueFromDom( const TQDomNode& node, bool* ok );
/*! Saves integer element for value \a value to \a doc document within tqparent element
\a parentEl. The value will be enclosed in "number" element and "elementName" element.
Example: saveNumberElementToDom(doc, parentEl, "height", 15) will create
\code
@@ -359,7 +359,7 @@ namespace KexiDB
KEXI_DB_EXPORT TQDomElement saveNumberElementToDom(TQDomDocument& doc, TQDomElement& parentEl,
const TQString& elementName, int value);
/*! Saves boolean element for value \a value to \a doc document within tqparent element
\a parentEl. Like saveNumberElementToDom() but creates "bool" tags. True/false values will be
saved as "true"/"false" strings.
\return the reference to element created with tag elementName. */
@@ -349,7 +349,7 @@ namespace KexiDB
/*! Convenience version of loadPropertyValueFromDom(). \return TQString value. */
KEXI_DB_EXPORT TQString loadStringPropertyValueFromDom( const TQDomNode& node, bool* ok );
- /*! Saves integer element for value \a value to \a doc document within tqparent element
+ /*! Saves integer element for value \a value to \a doc document within parent element
\a parentEl. The value will be enclosed in "number" element and "elementName" element.
Example: saveNumberElementToDom(doc, parentEl, "height", 15) will create
@@ -359,7 +359,7 @@ namespace KexiDB
KEXI_DB_EXPORT TQDomElement saveNumberElementToDom(TQDomDocument& doc, TQDomElement& parentEl,
const TQString& elementName, int value);
- /*! Saves boolean element for value \a value to \a doc document within tqparent element
+ /*! Saves boolean element for value \a value to \a doc document within parent element
\a parentEl. Like saveNumberElementToDom() but creates "bool" tags. True/false values will be
saved as "true"/"false" strings.